function []=pltseries0(y,y0,titl,xscale0,wind,varargin)

// PURPOSE: plots series... (scilab function plot2d, but with
// some scilab parameters fixed and new possibilities, such as
// ts, the mixing of bars and curves, the possibility to have 
// 2 different axes,...)
// ------------------------------------------------------------
// INPUT:
// * y = the (nxp) values real matrix of the graphed series
// * y0 = the value where to draw the x axis or [] if the user
//   wants the axis to be put a the y minimum value
// * titl = title of the graph
// * xscale0 = a (nx1) string vector representing the x scale
// * wind = the number of the window where to draw the graph
//   (-1 if the user wants to draw it on the currently opened
//    window)
// * varargin = optional arguments:
//   - 'styleg =xx' with xx integer row vector of size p
//     representing the location of the legend
//     (default: 5, that is the legend is placed interactively 
//      with the mouse, see legends in the help menu)
//   - 'style = xx' with xx integer row vector of size p
//     representing the line style of each series
//   - 'thickn = xx' with xx integer row vector of size p
//     representing the thickness of the line drawn for each
//     series (default all equal to 1)
//   - 'color = xx' with xx integer row vector of size p
//      representing the line color of each series
//   - 'leg = tit' with tit = title of the legend
//   - 'yaxis = xx' with xx integer row vector of size p
//     representing the axis for each series (1=left; 2=right)
//   - 'bars = xx' with xx integer row vector of size p
//     representing the nature of the representation of the 
//     series (1=bars; anything else = curves)
//   - 'x0(1)=xx' with xx integer representing the x location
//     of the first y axis (default: put at x=1) 
//   - 'x0(2)=xx' with xx integer representing the x location
//     of the second y axis (default: put at x=nobs) 
//   - 'just_scale=bool' with bool a boolean which is:
//      %T if you want the y scale to be exactly the length
//      [min(y),max(y)]
//      %f if you want the y scale to begin and end with
//      rounded numbers (default)
//   - 'reverse = xx' with xx integer row vector of size 2
//     of 0 and 1: 0 if series are drawn in increasing order
//                 1 if series are drawn in decreasing
//     (default: all series plotted in increasing order)
// ------------------------------------------------------------
// OUPTUT:
// nothing: all results are printed on the graphic window
// ------------------------------------------------------------
// Copyright: Eric Dubois 2002-2007
// http://dubois.ensae.net/grocer.html

// load the parameters that determines the fonts
load('SCI/macros/grocer/db/param_g.dat')

nargin=length(varargin)
[nobs,ny]=size(y)
// set default values
secondaxis=%f
sty=[1:ny]
styleg=6
bars=zeros(ny,1)
x0=[1 nobs]
x0given=%f
ydeb=[]
just_scale=%f
thickn=ones(ny,1)
xscale0=vec2row(xscale0)
font_leg=4
reverse=zeros(ny,1)
y_1=[1:ny]
y_2=[]

for i=1:nargin
   argi=varargin(i)
   indeq=strindex(argi,'=')
   begc=strsubst(part(argi,1:indeq-1),' ','')
   endc=part(argi,indeq+1:length(argi))
   if or(begc == ['styleg';'thickn';'style';'bars';'x0';...
        'font_leg';'reverse';'just_scale']) then
      execstr(argi)
   elseif begc == 'color' then
      pltcol=vec2row(evstr(endc))
   elseif begc == 'leg' then
      legend0=str2vec(varargin(i))
   elseif begc == 'yaxis' then
      execstr(argi)
      if or(yaxis~=1) then 
         y_1=find(yaxis == 1)
         y_2=find(yaxis ~= 1)
         secondaxis=%t
      end
   end 
end


min_x0=int(min(x0))
max_x0=int(max(x0))

if wind ~= -1 then
   scf(wind)
// clean the screen:
   clf(wind)
end

drawlater()

ny2=size(y_2,2)
nbars=sum(bars(y_1)==1)
if nbars ~= 0 then
// if there are bars in the graph, then the x axis is drawn at y=0
   y0=0
   if ~x0given then
      min_x0=0
   end
end

yext1=[]
yext2=[]
if min_x0 <=0 then
   yext1=%nan*ones(-min_x0+1,1)
end

if max_x0 > nobs then
   yext2=%nan*ones(max_x0-nobs+1,1)
end

xset("font size",min(font_axis,3))

// choose default colors
if ~exists('pltcol','local') then
   pltcol=[1 2 5 14 24 3:4 6:13]
   pltcol=pltcol(1:ny)
end

// in a graph with several bars (and maybe curves)
// width_bars is the length occupied by the bars (+ a blank)
// and xdeb is the n of the bar where the curves are located
// xending is the length remaining after the end of the curve

width_bars=nbars+bool2s(nbars>1)
xdeb=max(floor((width_bars+bool2s(nbars>1))/2),1)
xending=width_bars-xdeb

[y0,scale]=drawy(y(:,y_1)*(1-2*reverse(1)),font_axis,y0,1,'l',just_scale,reverse(1))
maxy1=max(scale)
miny1=min(scale)

if secondaxis then
   y2=y(:,y_2)*(1-reverse(2)*2)
   [newscale,miny2,maxy2]=yscale(y2,just_scale)
   maxy2=max(maxy2,newscale($))
   if or(bars(y_2) == 1) then
      miny2=min(miny2,newscale(1),0)
   else
      miny2=min(miny2,newscale(1))
   end

// determine the scaling factor applying to series on axis # 2:
// the size of the graph is determined by the first axis and 
// series on the second axis are adjusted to this size, with the 
// second axis keeping trace of the true intial values in newscale

   den=(maxy2-miny2) 
   cte=(miny1*maxy2-maxy1*miny2)/den
   deriv=(maxy1-miny1)/den

   y2=y2*deriv+cte 
   scale=newscale*deriv+cte
   newscale=newscale*(1-reverse(2))-reverse(2)*newscale

   if just_scale then
      drawaxis(y=scale,x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=string(newscale))
      drawaxis(y=[miny1 scale(1)],x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=emptystr(2,1))
      drawaxis(y=[scale(size(scale,2)) maxy1],x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=emptystr(2,1))
   else
      drawaxis(y=scale,x=max_x0,dir='r',tics='v',fontsize=font_axis,sub_int=0,val=string(newscale))
   end
end

xset("line style",1)
drawx(xscale0,max(width_bars,1),ref_nbinter,font_axis,y0,max(0,-min_x0+1),max(0,max_x0-nobs))

rectc=[1,miny1,max(width_bars,1)*(size(xscale0,2)+1)+max(0,-min_x0+1)+max(0,max_x0-nobs)+1,maxy1]

bari=0
ny1=size(y_1,2)
for i=1:ny1
   i1=y_1(i)
   yi=y(:,i1)*(1-2*reverse(1))
   if bars(i1) == 1 then
      bari=bari+1
      xset("thickness",1)
      yext=[yext1 ; yi .*. [0*[1:bari-1]' ; 1 ; 0*[bari+1:nbars+bool2s(nbars>2)]' ] yext2]
      [listx,listy]=dealyna(yext)
      for j=1:length(listx)
         plot2d3(listx(j),listy(j),pltcol(i1),axesflag=0,rect=rectc)
         g=gca()
         gc=g.children(1)
         polyl=gc.children
         polyl.thickness=thickn(i1)
         polyl.line_style=sty(i1)
      end
   else
      if nbars > 1 then
         yext=[yext1 %nan*ones(1,xdeb-1) interpln([xdeb+width_bars*[0:nobs-1] ; yi'],...
               [xdeb:xdeb+width_bars*(nobs-1)]) %nan*ones(1,xending) yext2]
      else
         yext=[yext1 yi' yext2]
      end
      [listx,listy]=dealyna(yext)

      for j=1:length(listx)
         plot2d(listx(j),listy(j),pltcol(i1),axesflag=0,rect=rectc)
         g=gca()
         gc=g.children(1)
         polyl=gc.children
         polyl.thickness=thickn(i1)
         polyl.line_style=sty(i1)
      end
   end
end

if secondaxis then

   for i=1:ny2
      i2=y_2(i)
      yi=y2(:,i)
      if bars(i2) == 1 then
         bari=bari+1
         xset("thickness",1)
         yext=[yext1 ; yi .*. [0*[1:bari-1]' ; 1 ; 0*[bari+1:nbars+bool2s(nbars>2)]' ] yext2]
         [listx,listy]=dealyna(yext)
         for j=1:length(listx)
            plot2d3(listx(j),listy(j),pltcol(i2),axesflag=0,rect=rectc)
         end
         g=gca()
         gc=g.children(1)
         polyl=gc.children
         polyl.thickness=thickn(i1)
         polyl.line_style=sty(i1)
      else
         if nbars > 1 then
            yext=[yext1 interpln([xdeb+width_bars*[0:nobs-1] ; yi'],[xdeb:xdeb+width_bars*(nobs-1)]) yext2]
         else
            yext=[yext1 yi' yext2]
         end
         xset("thickness",1+(nbars~=0))
         [listx,listy]=dealyna(yext)
         for j=1:length(listx)
            plot2d(listx(j),listy(j),pltcol(i2),axesflag=0,rect=rectc)
         end
         g=gca()
         gc=g.children(1)
         polyl=gc.children
         polyl.thickness=thickn(i2)
         polyl.line_style=sty(i2)
      end
// now change the curves style to the one given by the user
// note that the last curve is in the first place in 
   end
//   gc_axis=g.children($)
//   gc_axis.tics_labels=string(newscale)

end

f_title=max(1,5-floor(length(titl)/thresh))

a = gca() ; // get the current axis 
tit = a.title ; // get the handle of the title 
tit.text = titl  // set the title
tit.font_size = f_title ; // change the font_size 
drawnow()

if exists('legend0','local') then
   legends_groc(legend0,[evstr(pltcol) ; sty],styleg,font_leg)
   h=gce()
   nleg=size(legend0,'*')
   for i=1:nleg
      hi=h.children(2*(nleg-i+1))
      hi.thickness=thickn(i)
   end
end


endfunction

